Stan Math Library: stan/math/prim/scal/meta/is_var_or_arithmetic.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Classes | Namespaces
is_var_or_arithmetic.hpp File Reference
`#include <stan/math/prim/scal/meta/is_var.hpp>`
`#include <stan/math/prim/scal/meta/scalar_type.hpp>`
`#include <boost/type_traits/is_arithmetic.hpp>`

Go to the source code of this file.

## Classes
struct | stan::is_var_or_arithmetic< T1, T2, T3, T4, T5, T6 >

## Namespaces
| stan

[ Stan Home Page ] © 2011–2016, Stan Development Team.